function [Q,st]=GaussChe(funfcn,a,b,n,trace)
%---------------------------------------------------------------------------    
%  Q=GaussChe(funfcn,a,b,n,trace)
%  The function GaussChe calculates an approximate value of the
%  integral from f(x)(1-x.^2).^(-1/2) in the interval [a,b] by the Gauss-    
%  -Chebyshev quadrature formula.                                           
%  Data:                                                                    
%    a,b   - the ends of the integration interval,                          
%    funfcn- a string containing the name of the function,                                                                       
%    n     - order of quadrature                                                                 
%    trace - if 1 then traces the function evaluations with a point plot of the integrand  
%            the value of k-th coefficient,
% Note: n & trace are shrewd parameters, so it isn't necessary to define
% 	them (n=2 trace=0 by default)
%  Result:                                                                  
%    GaussChe('f',a,b,n,st) - approximate value of the integral.            
%  Other parameters:                                                        
%    st - a variable which within the function GaussChebyshev is assigned   
%         the value of:                                                     
%           1, if n<0,                                                      
%           0, otherwise.                                                   
%         Note: If st=1, then GaussChe('f',a,b,n,st) is not calculated.     
%---------------------------------------------------------------------------
if nargin < 4, n=2; trace = 0; end
if nargin < 5, trace = 0; end

if a==b trace=0; end
if n>=0
  st=0;
  p=3.1415926535897/(2*n+2);
  s=0;
  for k=0:n
    t1=0.5*(a+b)+0.5*(b-a)*cos((2*k+1)*p);
    t2=sqrt(1-(cos((2*k+1)*p))^2);	
    s=s+feval(funfcn,t1)*t2;
  end
  Q=0.5*(b-a)*3.1415926535897*s/(n+1);  
else st=1
end

if (trace)&(st==0)
  nrfig=figure('name','Gauss-Chebyshev');
  clf, %whitebg
  x= a:0.01*(b-a):b;
  y=feval(funfcn,x);
  fplot(funfcn,[min([a b]) max([a b])]),%axis([a b min(y) max(y)])
  title(['Funkcja podcakowa w przedziale (',num2str(a,9),';',num2str(b,9),')']); 
  pause
  vecxx=-0.99:0.01:0.99;
  vecyy=0.5*(b-a)*feval(funfcn,0.5*(a+b)+0.5*(b-a)*vecxx);
  clf, plot(vecxx,vecyy),grid,title('Przeskalowanie do przedziau (-1,1)');
  handle=line([-1 1],[0 0]);
  if get(gcf,'color')==[0 0 0] kolor='white'; else kolor='black';end
  set(handle,'color',kolor); 
  pause;
  hold on;
  vecx=cos((2*(0:n)+1)*pi/(2*n+2));        
  vecy1=0.5*(b-a).*feval(funfcn,0.5*(a+b)+0.5*(b-a).*vecx);
  vecy=vecy1.*sqrt(1-(vecx).^2);
  plot(vecx,vecy1,'ro'),title('Wzy kwadratury (press Enter)'),pause 
  %vecfx=lagrange(vecxx,vecx,vecy,n)./sqrt(1-(vecxx).^2);%interpolacja wielomianem	
  cfx=newcoeff(n,vecx,vecy);
  vecfx=0;
    for k=0:n
      vecfx=vecfx+cfx(n-k+1).*vecxx.^k;
    end	
  vecfx=vecfx./sqrt(1-(vecxx).^2);
  plot(vecxx,vecfx,'b-')
  title('Interpolacja (press Enter)'),pause
  title(['Wynik cakowania= ',num2str(Q,9)]),pause
  hold off
  close	
end
