function [Q,st]=GHermite(funfcn,n,trace)
%---------------------------------------------------------------------------
%  GHermite(funfcn,n,trace)
%  The function GHermite calculates an approximate value of the         
%  integral from e^(-x*x)*f(x) in the interval (-infinity,+infinity) by the 
%  Gauss-Hermite quadrature formula.                                        
%  Data:                                                                    
%    funfcn -a name of function which for the given x calculates the value 
%        of f(x) occurring in the integrand,                                
%    n - number of nodes minus 1 (the nodes are numbered from 0 to n),      
%  Result:                                                                  
%    GHermite('f',n,trace) - approximate value of the integral.            
%  Other parameters:                                                        
%    st - a variable which within the function GaussHermite is assigned the 
%         value of:                                                         
%           1, if n<1,                                                      
%           0, otherwise.                                                   
%         Note: If st=1, then GHermite(f,n,trace) is not calculated.     
%---------------------------------------------------------------------------
if nargin < 2, n=8; trace = 0; end
if nargin < 3, trace = 0; end
rootab=[-0.7071067811865475 0 0 0 0;
	-1.224744871391589 0 0 0 0;
	-1.650680123885785 -0.5246476232752903 0 0 0;
	-2.020182870456086 -0.9585724646138185 0 0 0;
	-2.350604973674492 -1.335849074013697 -0.4360774119276165 0 0;
	-2.651961356835234 -1.673551628767472 -0.8162878828589647 0 0;
	-2.930637420257244 -1.981656756695843 -1.157193712446780 -0.3811869902073221 0;
	-3.190993201781528 -2.266580584531843 -1.468553289216668 -0.7235510187528376 0;];
if (n>0)&(n<=50)
  st=0;
  %s=0;
  ar=2;
  l=floor(n/2);
  h0=1;
  x1=-10:(20/(n+1)):10;
  if n>8
    h1=2*x1;
    for m=1:n
      h2=2*(x1.*h1-m*h0);
      h0=h1;
      h1=h2;
    end
    veccfx=newcoeff(n+1,x1,h2);
    rootvec=roots1(veccfx).';
  if n==2*l rootvec(l+1)=0;end    
  else
    rootvec=zeros(1,n+1); 
    for k=0:n
      if (k<=l)
        rootvec(k+1)=rootab(n,k+1);
      else
        rootvec(k+1)=-rootab(n,n-k+1);
      end
    end
  end
  x1=rootvec;
  h0=1;
  h1=2*x1;
  for m=1:n-1
    h2=2*(x1.*h1-m*h0);
    h0=h1;
    h1=h2;
  end
  y=feval(funfcn,x1).*exp(x1.*x1);
  x1=y./(h1.*h1);
  s=sum(x1);
  for k=2:n ar=2*k*ar;end	
  Q=ar*sqrt(pi)*s/(n+1);
else st=1;
end

if (trace)&(st==0)
  nrfig=figure('name','Gauss-Hermite');
  clf, %whitebg
  vecx=rootvec;
  vecy1=feval(funfcn,vecx);
  vecy=feval(funfcn,vecx).*exp(vecx.*vecx);
  b=ceil(max(vecx));
  fplot(funfcn,[-1.1*b 1.1*b]),
  title(['Funkcja podcakowa (press Enter)']); 
  pause
  vecxx=-1.1*b:0.01*b:b*1.1;
  vecyy=feval(funfcn,vecxx);
  hold on;        
  plot(vecx,vecy1,'ro'),grid,title('Wzy kwadratury (press Enter)'),pause 
  %vecfx=lagrange(vecxx,vecx,vecy,n)./exp(vecxx.*vecxx);%interpolacja funkcj W(x)*w(x)
  cfx=newcoeff(n,vecx,vecy);
  vecfx=0;
    for k=0:n
      vecfx=vecfx+cfx(n-k+1).*vecxx.^k;
    end	
  vecfx=vecfx./exp(vecxx.*vecxx);
  plot(vecxx,vecfx,'b-') %axis([-1.1*b 1.1*b min(vecyy) max(vecyy)])
  title('Interpolacja (press Enter)'),pause
  title(['Wynik cakowania= ',num2str(Q,9)]),pause
  hold off
  close
end