function [Q,st]=Glaguer(funfcn,a,n,trace)
%---------------------------------------------------------------------------
%  Q=Glaguer(funfcn,a,n,trace)
%  The function GLaguerre calculates an approximate value of the        
%  integral from e^(-x)*f(x) in the interval [0,infinity) by the Gauss-     
%  -Laguerre quadrature formula.                                            
%  Data:                                                                    
%    funfcn - a name of function which for the given x calculates the value 
%        of f(x) occurring in the integrand,                                
%    n - number of nodes minus 1 (the nodes are numbered from 0 to n),                                                       
%  Result:                                                                  
%    GLaguer('f',a,n,trace) - approximate value of the integral.           
%  Other parameters:                                                        
%    st - a variable which within the function GaussLaguerre is assigned    
%         the value of:                                                     
%           1, if n<1,                                                      
%           0, otherwise.                                                   
%         Note: If st=1, then GLaguer(f,a,n,trace) is not calculated.                                                                      
%---------------------------------------------------------------------------
if nargin < 3, n=8; trace = 0; end
if nargin < 4, trace = 0; end
rootab=[0.5857864376269050 3.414213562373095 0 0 0 0 0 0 0;
	0.4157745567834791 2.294280360279042 6.289945082937479 0 0 0 0 0 0;
	0.3225476896193923 1.745761101158347 4.536620296921128 9.395070912301133 0 0 0 0 0;
	0.2635603197181409 1.413403059106517 3.596425771040722 7.085810005858838 12.64080084427578 0 0 0 0;
	0.2228466041792607 1.188932101672623 2.992736326059314 5.775143569104511 9.837467418382590 15.98287398060170 0 0 0;
	0.1930436765603624 1.026664895339192 2.567876744950746 4.900353084528766 8.182153444562861 12.73418029179781 19.39572786226254 0 0;
	0.1702796323051010 0.903701776799380 2.251086629866131 4.266700170287659 7.045905402393466 10.75851601018100 15.74067864127800 22.86313173688926 0;
	0.1523222277318082 0.807220022742256 2.005125155619347 3.783473973331233 6.204956777876613 9.372985251687576 13.46623691109209 18.83359778899170 26.37407189092738;];
if (n>0)&(n<100)
  st=0;
  s=0;
  ar=1;
  if n>8
    l0=1;
    x1=0:(20/(n+1)):20;
    l1=1-x1;    
    p1=x1;
    for m=1:n
      l2=((2*m+1)-x1).*l1-m*m*l0;
      l0=l1;
      l1=l2;
    end
    veccfx=round(newcoeff(n+1,x1,l2));
    rootvec=roots1(veccfx).';
  else
    rootvec=rootab(n,1:n+1);
  end
  l0=1;
  x1=rootvec;
  l1=1-x1;
  for m=1:n-1
    l2=((2*m+1)-x1).*l1-m*m*l0;
    l0=l1;
    l1=l2;
  end
  y=feval(funfcn,x1+a).*exp(x1);
  x1=x1.*y./(l1.*l1); 
  s=sum(x1);
  for k=2:n ar=k*ar;end
  Q=exp(-a)*ar*ar*s/((n+1)*(n+1));
else st=1;
end

if (trace)&(st==0)
  nrfig=figure('name','Gauss-Laguerre');
  clf, %whitebg
  vecx=rootvec;
  vecy1=feval(funfcn,vecx+a);
  vecy=vecy1.*exp(vecx);
  b=ceil(max(vecx));
  fplot(funfcn,[a b+10*abs(a)]), 
  title(['Funkcja podcakowa w przedziale (',num2str(a,9),';inf)']); 
  pause
  vecxx=0:0.01*b:b;
  vecyy=feval(funfcn,vecxx+a);
  clf, plot(vecxx,vecyy),grid,title(['Podstawienie x=t+',num2str(a),' (',num2str(a),';inf)=>(0;inf)']);
  set(gca,'XLim',[0 b]),pause
  hold on;        
  plot(vecx,vecy1,'ro'),title('Wzy kwadratury (press Enter)'),pause 
  %vecfx=lagrange(vecxx,vecx,vecy,n).*exp(-vecxx);%interpolacja funkcj=wielomian*funkcja wag.;W(x)*w(x)	
  cfx=newcoeff(n,vecx,vecy);
  vecfx=0;
    for k=0:n
      vecfx=vecfx+cfx(n-k+1).*vecxx.^k;
    end	
  vecfx=vecfx.*exp(-vecxx);
  plot(vecxx,vecfx,'b-'), 
  title('Interpolacja (press Enter)'),pause
  title(['Wynik cakowania= ',num2str(Q,9)]),pause
  hold off
  close	
end