function [xout, nr_it, err] = Jacobi(xin,A,b,eps,max_it)
%Rozwizywanie ukadw rwna liniowych metod iteracji prostej 
%function [xout, nr_it, err] = Jacobi(xin,A,b,eps,max_it)
%
%Parametry wejciowe:
%xin - wektor kolumnowy przyblienia pocztkowego
%A - macierz ukadu
%b - wektor kolumnowy definiujcy praw stron ukadu
%max_it - maksymalna liczba iteracji do wykonania
%Parametry wyjciowe:
%xout - rozwiazanie
%nr_it - liczba wykonanych iteracji
%err - tablica bdu w kolejnych iteracjach

%wyznaczenie macierzy C i wektora g schematu iteracyjnego
D = size(A); 
if (D(1)~=D(2)) error('Macierz ukladu A musi byc kwadratowa'); end;
a = diag(A);
C = diag(ones(1,D(1)))-A./a(1:length(a),ones(1,length(a)));
if norm(C)>1 error('Norma macierzy C=I-diag(A)\A > 1 => metoda jest rozbiena!'); end; 
g = b./a;

%krok iteracyjny
err = zeros(1,max_it);
xout = zeros(D(1),1);
for i=1:max_it
   xout = C*xin+g;
   err(i) = norm(xout-xin);         
   if (err(i)<=eps) break; end;
   xin=xout;
end;
nr_it = i;
err = err(1:i);