function [coeff,st]=Newcoeff(n,x,f);
%---------------------------------------------------------------------------
%  Newcoeff(n,x,f)
%  The procedure Newcoeff calculates coefficients of a polynomial      
%  given by Newton's interpolatory divided-difference formula.              
%  Data:                                                                    
%    n - number of nodes minus 1 (the degree of polynomial is at most n),   
%    x - an array containing the values of nodes,                           
%    f - an array containing the values of function                                                   
%  Result:                                                                  
%    coeff - an array of coefficients of polynomial (the element f[i] contains  
%        the value of coefficient before x.^(n-i); i=0,1,...,n).             
%  Other parameters:                                                        
%   st - a variable which within the procedure Newtoncoeffns is assigned   
%         the value of:                                                     
%           1, if n<0, the function does nothing                                                     
%           0, otherwise.                                                  
%---------------------------------------------------------------------------
coeff=zeros(1,n+1);
if n<0
  st=1
else
  st=0;
  if n>0    
    for k=1:n
      for i=1:n-k+1
        f(i)=(f(i+1)-f(i))/(x(i+k)-x(i));
      end
    end 
  end
  for i=1:n
    xi=x(i+1);
    for j=i:-1:1
      f(j+1)=f(j+1)-f(j)*xi;
    end
  end
  coeff=f;
end