function [xvect,xdif,fx,nit]=chord(a,b,x0,nmax,toll,fun)
%function [xvect,xdif,fx,nit]=chord(a,b,x0,nmax,toll,fun)
%Chord method of the 1 variable non-linear equation root finding
%
%OUTPUT PARAMETERS
%xvect -- x(k) sequence
%xdif -- x(k+1)-x(k) sequence
%fx -- f(x(k)) sequence
%nit -- number of iterations to convergence
%
%INPUT PARAMETERS
%a,b -- end points of the search interval
%x0 -- starting point
%nmax -- maximal number of iteratons
%toll -- fixed tollerance
%fun -- external function f of the x variable
x=a; fa=eval(fun); x=b; fb=eval(fun);
r=(fb-fa)/(b-a);
err=toll+1; nit=0; xvect=x0; x=x0;
fx=eval(fun); xdif=[];
while (nit < nmax & err > toll)
   nit=nit+1; x=xvect(nit);
   xn=x-fx(nit)/r; err=abs(xn-x);
   xdif=[xdif; err]; x=xn;
   xvect=[xvect; x];
   fx=[fx; eval(fun)];
end;