function [xvect,xdif,fx,nit]=regfalsi(xm1,x0,nmax,toll,fun)
%function [xvect,xdif,fx,nit]=regfalsi(xm1,x0,nmax,toll,fun)
% Regula Falsi method of the 1 variable non-linear equation root finding
%
%OUTPUT PARAMETERS
%xvect -- x(k) sequence
%xdif -- x(k+1)-x(k) sequence
%fx -- f(x(k)) sequence
%nit -- number of iterations to convergence
%
%INPUT PARAMETERS
%xm1 -- first point
%x0 -- starting point
%nmax -- maximal number of iteratons
%toll -- fixed tollerance
%fun -- external function f of the x variable
nit=0; x=xm1; f=eval(fun); fx=[f]; x=x0; f=eval(fun); fx=[fx; f];
xvect=[xm1;x0]; xdif=[]; f=toll+1; kprime=1;
while (nit < nmax & abs(f) > toll),
   nit=nit+1; dim=length(xvect);
   x=xvect(dim); fxk=eval(fun); xk=x; i=dim;
   while (i>=kprime),
      i=i-1; x=xvect(i); fxkpr=eval(fun);
      if(fxkpr*fxk<0),
         xkpr=x;
         kprime=i;
         break;
      end;
   end;
   x=xk-fxk*(xk-xkpr)/(fxk-fxkpr);
   xvect=[xvect;x]; f=eval(fun);
   fx=[fx; f]; err=abs(x-xkpr);
   xdif=[xdif; err];
end;