function [xvect,xdif,fx,nit]=secant(xm1,x0,nmax,toll,fun)
%function [xvect,xdif,fx,nit]=secant(xm1,x0,nmax,toll,fun)
% Secant method of the 1 variable non-linear equation root finding
%
%OUTPUT PARAMETERS
%xvect -- x(k) sequence
%xdif -- x(k+1)-x(k) sequence
%fx -- f(x(k)) sequence
%nit -- number of iterations to convergence
%
%INPUT PARAMETERS
%xm1 -- first point
%x0 -- starting point
%nmax -- maximal number of iteratons
%toll -- fixed tollerance
%fun -- external function f of the x variable
x=xm1; fxm1=eval(fun); xvect=[x]; fx=[fxm1]; 
x=x0; fx0=eval(fun);
xvect=[xvect;x]; fx=[fx;fx0]; err=toll+1;
nit=0; xdif=[];
while (nit < nmax & err > toll),
   nit=nit+1;
   x=x0-fx0*(x0-xm1)/(fx0-fxm1);
   xvect=[xvect;x];
   fnew=eval(fun); fx=[fx; fnew]; err=abs(x0-x); xdif=[xdif;err];
   xm1=x0; fxm1=fx0; x0=x; fx0=fnew;
end;